@@ -700,7 +700,7 @@ class AutostartRow(Gtk.ListBoxRow):
         label = Gtk.Label(_("Delay"))
         self.delay_box.pack_start(label, False, False, 0)
         self.delay_time_label = Gtk.Label()
-        self.delay_time_label.set_text(_("%s s") % delay_time_markup)
+        self.delay_time_label.set_markup(_("%s s") % delay_time_markup)
         self.delay_time_label.get_style_context().add_class("dim-label")
         self.delay_box.pack_start(self.delay_time_label, False, False, 0)
         grid.attach_next_to(self.delay_box, self.desc_box, Gtk.PositionType.RIGHT, 1, 1)
@@ -728,7 +728,7 @@ class AutostartRow(Gtk.ListBoxRow):
 
         self.name_label.set_markup("<b>{}</b>".format(name_markup))
         self.comment_label.set_markup("<small>{}</small>".format(comment_markup))
-        self.delay_time_label.set_markup(delay_time_markup)
+        self.delay_time_label.set_markup(_("%s s") % delay_time_markup)
         self.delay_box.set_visible(delay_time_markup != "0")
 
     def on_switch_activated(self, switch, gparam):
